@@ -25,11 +25,11 @@
 #include <QCheckBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QRandomGenerator>
 #include <QSlider>
 #include <QTimer>
 #include <KConfigGroup>
 #include <KLineEdit>
-#include <KRandom>
 #include <KLocalizedString>
 //BEGIN Kolf::Bumper
 
@@ -51,7 +51,7 @@ bool Kolf::Bumper::collision(Ball* ball)
 	Vector betweenVector(ball->pos() - pos());
 	betweenVector.setMagnitudeDirection(speed,
 		// add some randomness so we don't go indefinitely
-		betweenVector.direction() + deg2rad((KRandom::random() % 3) - 1)
+		betweenVector.direction() + deg2rad(QRandomGenerator::global()->bounded(3) - 1)
 	);
 
 	ball->setVelocity(betweenVector);
@@ -282,7 +282,7 @@ void Kolf::RectangleItem::moveBy(double dx, double dy)
 	Tagaro::SpriteObjectItem::moveBy(dx, dy);
 	//move myself
 	const QPointF pos = this->pos();
-	for (Kolf::Wall* wall : qAsConst(m_walls))
+	for (Kolf::Wall* wall : std::as_const(m_walls))
 		if (wall)
 			wall->setPos(pos);
 	//update Z order
@@ -298,7 +298,7 @@ void Kolf::RectangleItem::moveBy(double dx, double dy)
 void Kolf::RectangleItem::setWallColor(const QColor& color)
 {
 	m_wallPen = QPen(color.darker(), 3);
-	for (Kolf::Wall* wall : qAsConst(m_walls))
+	for (Kolf::Wall* wall : std::as_const(m_walls))
 		applyWallStyle(wall);
 }
 
